/*
  Remduino.h - Library for communication with REMLab
  Released into the public domain.
*/
#ifndef Remduino_h
#define Remduino_h

#define REM_DIV 0xFF
#define REM_MAXDEV 63
#define REM_SEND_QUEUE_LEN 16

#include "Arduino.h"

struct measureBindConf
{
	int pinNum;
	bool analog;
	int deviceNum;
	unsigned int (*func)(unsigned int input);
};

struct valueToSend
{
	int deviceNum;
	unsigned int value;
};

class Remduino
{
  public:
    Remduino();
    void bindControl(int pin,int device);
	void unbindControl(int device);
	
	void bindControlFunction(int device,void (*f)(unsigned int input));
	void unbindControlFunction(int device);
	
	void bindMeasure(int pin,int device,bool analog);
	void bindMeasure(int pin, int device, bool analog, unsigned int (*f)(unsigned int input));
	void unbindMeasure(int pin);
	
	void sendValue(int device,unsigned int value);
	
    void process();
  private:
    measureBindConf _measureBinds[REM_MAXDEV];
    int _measureCount;
	
	valueToSend _sendQueue[REM_SEND_QUEUE_LEN];
	int _sendCount;
	
    int _controlBinds[REM_MAXDEV];
	void (*_controlFuncs[REM_MAXDEV])(unsigned int input);
	bool _synced;
	bool _halfSynced;
};



#endif