/**
 * iSES Remote Lab SDK (c) by J.Dvorak, P.Kuriscak, F.Lustig
 *
 * This file is licensed under a Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 *
 * Copy of license along with attribution guidelines is distributed together with this work in LICENSE.txt file.
 * License text is also available online on <http://creativecommons.org/licenses/by-nc-sa/4.0/>.
 */

Flotr.Series.prototype.getRangeOld = Flotr.Series.prototype.getRange;


Flotr.Series.prototype.getRange = function(){
	var range = $.proxy(Flotr.Series.prototype.getRangeOld,this)();
	var xadjusted = VLH.CenterAndSetRange(range.xmin,range.xmax,this.xaxis.options.center,this.xaxis.options.minRange,this.xaxis.options.maxRange);
	var yadjusted = VLH.CenterAndSetRange(range.ymin,range.ymax,this.yaxis.options.center,this.yaxis.options.minRange,this.yaxis.options.maxRange);

	range.xmin = xadjusted.min;
	range.xmax = xadjusted.max;

	range.ymin = yadjusted.min;
	range.ymax = yadjusted.max;

	return range;
};

/**
 * Special type of point drawing functionality which draws simple boxes
 * using series color.
 *
 * Tries to reduce amount of anti-aliasing applied.
 */
Flotr.addType('boxes', {
	options: {
		show: false,
		size: 2,
		debugGraph: false,
	},

	draw : function (options) {
		var context = options.context;
		context.save();

		context.fillStyle = options.color;
		this.plot(options);

		context.restore();
	},

	plot : function (options) {
		var data = options.data;
		var context = options.context;
		var xScale = options.xScale;
		var yScale = options.yScale;

		var size = options.size;
		var halfSize = size / 2;
		var offset = -halfSize;

		var perPointColors = (data.length > 0) && (data[0].length > 2);
		var lastColor = undefined;

		var startTime;
		if (options.debugGraph) {
			startTime = performance.now()
		}

		for (var i = 0; i < data.length; ++i) {
			var yData = data[i][1];
			if (yData == null) {
				continue;
			}
			var x = Math.round(xScale(data[i][0]));
			if ((x < 0) || (x > options.width)) {
				continue;
			}
			var y = Math.round(yScale(yData));
			if ((y < 0) || (y > options.height)) {
				continue;
			}
			if (perPointColors) {
				var newColor = data[i][2];
				if (lastColor !== newColor) {
					lastColor = newColor;
					context.fillStyle = newColor;
				}
			}
			context.fillRect(x + offset, y + offset, size, size);
		}

		if (options.debugGraph) {
			var endTime = performance.now();
			console.log("Points " + data.length + " duration " + (endTime - startTime) + "ms");
		}
	}
});
